pycocoa.geometry.Point

Package pycocoa :: Module geometry :: Class Point |
[frames] | no frames]

# Class Point

      object --+
               |
    bases._Type0 --+
                   |
                  Point

Known Subclasses:
  - Point2

Python Type, wrapping an ObjC `NSPoint_t`.

Instance Methods
__init__(self, point) New Point from another Point, `list`, `tuple` or `NSPoint_t`. |
__str__(self) str(x) |
Inherited from `bases._Type0`: `__repr__`, `type2strepr` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
| point Get the 2-tuple (x, y) coordinate of (`float` or `int`).
| x Get the x coordinate (`float` or `int`).
| y Get the y coordinate (`float` or `int`).
Inherited from `bases._Type0`: `NS`, `NSDelegate`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__(self, point) (Constructor) |
New Point from another Point, `list`, `tuple` or `NSPoint_t`. Overrides: object.__init__

### __str__(self) (Informal representation operator) |
str(x) Overrides: object.__str__ (inherited documentation)

Property Details

### point Get the 2-tuple (x, y) coordinate of (`float` or `int`). Get Method: point(self) - Get the 2-tuple (x, y) coordinate of (`float` or `int`). Set Method: point(self, point)

### x Get the x coordinate (`float` or `int`). Get Method: x(self) - Get the x coordinate (`float` or `int`). Set Method: x(self, x)

### y Get the y coordinate (`float` or `int`). Get Method: y(self) - Get the y coordinate (`float` or `int`). Set Method: y(self, y)